@@ -52,6 +52,10 @@ class Identity(object):
     @ivar account_name: See L{BrokerConfiguration}.
     @ivar registration_password: See L{BrokerConfiguration}.
     @ivar tags: See L{BrokerConfiguration}
+
+    @param config: A L{BrokerConfiguration} object, used to set the
+        C{computer_title}, C{account_name} and C{registration_password}
+        instance variables.
     """
 
     secure_id = persist_property("secure-id")
@@ -62,11 +66,6 @@ class Identity(object):
     tags = config_property("tags")
 
     def __init__(self, config, persist):
-        """
-        @param config: A L{BrokerConfiguration} object, used to set the
-            C{computer_title}, C{account_name} and C{registration_password}
-            instance variables.
-        """
         self._config = config
         self._persist = persist.root_at("registration")
 
@@ -105,6 +104,9 @@ class RegistrationHandler(object):
         if self._config.cloud:
             return bool(not id.secure_id
                         and self._message_store.accepts("register-cloud-vm"))
+        elif self._config.provisioning_otp:
+            return (not id.secure_id) and\
+                self._message_store.accepts("register-provisioned-machine")
         return bool(not id.secure_id and id.computer_title and id.account_name
                     and self._message_store.accepts("register"))
 
@@ -146,8 +148,9 @@ class RegistrationHandler(object):
                 "/meta-data/local-hostname",
                 "/meta-data/public-hostname",
                 "/meta-data/ami-launch-index",
-                "/meta-data/kernel-id",
-                "/meta-data/ami-id"]
+                "/meta-data/ami-id",
+                "/meta-data/local-ipv4",
+                "/meta-data/public-ipv4"]
             # We're not using a DeferredList here because we want to keep the
             # number of connections to the backend minimal. See lp:567515.
             for path in paths:
@@ -158,12 +161,18 @@ class RegistrationHandler(object):
                 lambda ignore: self._fetch_async(
                     EC2_API + "/meta-data/ramdisk-id").addErrback(log_failure))
             deferred.addCallback(ec2_data.append)
+            # And same for kernel
+            deferred.addCallback(
+                lambda ignore: self._fetch_async(
+                    EC2_API + "/meta-data/kernel-id").addErrback(log_failure))
+            deferred.addCallback(ec2_data.append)
 
             def record_data(ignore):
                 """Record the instance data returned by the EC2 API."""
                 (raw_user_data, instance_key, reservation_key,
                  local_hostname, public_hostname, launch_index,
-                 kernel_key, ami_key, ramdisk_key) = ec2_data
+                 ami_key, local_ip, public_ip, ramdisk_key,
+                 kernel_key) = ec2_data
                 self._ec2_data = {
                     "instance_key": instance_key,
                     "reservation_key": reservation_key,
@@ -172,9 +181,11 @@ class RegistrationHandler(object):
                     "launch_index": launch_index,
                     "kernel_key": kernel_key,
                     "ramdisk_key": ramdisk_key,
-                    "image_key": ami_key}
+                    "image_key": ami_key,
+                    "public_ipv4": public_ip,
+                    "local_ipv4": local_ip}
                 for k, v in self._ec2_data.items():
-                    if v is None and k == "ramdisk_key":
+                    if v is None and k in ("ramdisk_key", "kernel_key"):
                         continue
                     self._ec2_data[k] = v.decode("utf-8")
                 self._ec2_data["launch_index"] = int(
@@ -275,8 +286,8 @@ class RegistrationHandler(object):
                 with_word = ["without", "with"][bool(id.registration_password)]
                 with_tags = ["", u"and tags %s " % tags][bool(tags)]
                 logging.info(u"Queueing message to register with account %r %s"
-                              "%s a password." % (id.account_name, with_tags,
-                              with_word))
+                             "%s a password." % (id.account_name, with_tags,
+                                                 with_word))
                 message = {"type": "register",
                            "computer_title": id.computer_title,
                            "account_name": id.account_name,
@@ -285,6 +296,12 @@ class RegistrationHandler(object):
                            "tags": tags,
                            "vm-info": get_vm_info()}
                 self._exchange.send(message)
+            elif self._config.provisioning_otp:
+                logging.info(u"Queueing message to register with OTP as a"
+                             u" newly provisioned machine.")
+                message = {"type": "register-provisioned-machine",
+                           "otp": self._config.provisioning_otp}
+                self._exchange.send(message)
             else:
                 self._reactor.fire("registration-failed")
 
