@@ -64,15 +64,47 @@ class ConfigurationTests(LandscapeTest):
 
     def test_intervals_are_ints(self):
         """
-        The 'urgent_exchange_interval and 'exchange_interval' values specified
-        in the configuration file are converted to integers.
+        The 'urgent_exchange_interval, 'exchange_interval' and 'ping_interval'
+        values specified in the configuration file are converted to integers.
         """
         filename = self.makeFile("[client]\n"
                                  "urgent_exchange_interval = 12\n"
-                                 "exchange_interval = 34\n")
+                                 "exchange_interval = 34\n"
+                                 "ping_interval = 6\n")
 
         configuration = BrokerConfiguration()
         configuration.load(["--config", filename, "--url", "whatever"])
 
         self.assertEqual(configuration.urgent_exchange_interval, 12)
         self.assertEqual(configuration.exchange_interval, 34)
+        self.assertEqual(configuration.ping_interval, 6)
+
+    def test_missing_url_is_defaulted(self):
+        """
+        Test that if we don't explicitly pass a URL, then this value is
+        defaulted.
+        """
+        filename = self.makeFile("[client]\n")
+
+        configuration = BrokerConfiguration()
+        configuration.load(["--config", filename])
+
+        self.assertEqual(configuration.url,
+                         "https://landscape.canonical.com/message-system")
+
+    def test_server_autodiscover_handling(self):
+        """
+        server_autodiscover is parsed and converted to a boolean value by
+        load().
+        """
+        configuration = BrokerConfiguration()
+        configuration.load([])
+        self.assertEqual(configuration.server_autodiscover, False)
+
+        configuration = BrokerConfiguration()
+        configuration.load(["--server-autodiscover=true"])
+        self.assertEqual(configuration.server_autodiscover, True)
+
+        configuration = BrokerConfiguration()
+        configuration.load(["--server-autodiscover=false"])
+        self.assertEqual(configuration.server_autodiscover, False)
