@@ -4,6 +4,7 @@ This module, and specifically L{LandscapeSetupScript}, implements the support
 for the C{landscape-config} script.
 """
 
+import json
 import base64
 import time
 import sys
@@ -18,7 +19,7 @@ from landscape.lib.tag import is_valid_tag
 from landscape.sysvconfig import SysVConfig, ProcessError
 from landscape.lib.amp import MethodCallError
 from landscape.lib.twisted_util import gather_results
-from landscape.lib.fetch import fetch, FetchError
+from landscape.lib.fetch import fetch, FetchError, HTTPCodeError
 from landscape.reactor import TwistedReactor
 from landscape.broker.registration import InvalidCredentialsError
 from landscape.broker.config import BrokerConfiguration
@@ -68,9 +69,8 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
     unsaved_options = ("no_start", "disable", "silent", "ok_no_register",
                        "import_from")
 
-    def __init__(self, fetch_import_url):
+    def __init__(self):
         super(LandscapeSetupConfiguration, self).__init__()
-        self._fetch_import_url = fetch_import_url
 
     def _load_external_options(self):
         """Handle the --import parameter.
@@ -89,7 +89,7 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
                         os.environ["http_proxy"] = self.http_proxy
                     if self.https_proxy:
                         os.environ["https_proxy"] = self.https_proxy
-                    content = self._fetch_import_url(self.import_from)
+                    content = self.fetch_import_url(self.import_from)
                     parser.readfp(StringIO(content))
                 elif not os.path.isfile(self.import_from):
                     raise ImportOptionError("File %s doesn't exist." %
@@ -109,6 +109,21 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             options.update(self._command_line_options)
             self._command_line_options = options
 
+    def fetch_import_url(self, url):
+        """Handle fetching of URLs passed to --url."""
+
+        print_text("Fetching configuration from %s..." % url)
+        error_message = None
+        try:
+            content = fetch(url)
+        except FetchError, error:
+            error_message = str(error)
+        if error_message is not None:
+            raise ImportOptionError(
+                "Couldn't download configuration from %s: %s" %
+                (url, error_message))
+        return content
+
     def make_parser(self):
         """
         Specialize the parser, adding configure-specific options.
@@ -378,7 +393,7 @@ class LandscapeSetupScript(object):
             if self._get_invalid_tags(self.config.tags):
                 self.show_help("Tag names may only contain alphanumeric "
                               "characters.")
-                self.config.tags = None # Reset for the next prompt
+                self.config.tags = None  # Reset for the next prompt
             else:
                 break
 
@@ -409,18 +424,119 @@ class LandscapeSetupScript(object):
 
 
 def setup_init_script_and_start_client():
+    "Configure the init script to start the client on boot."
     # XXX This function is misnamed; it doesn't start the client.
     sysvconfig = SysVConfig()
     sysvconfig.set_start_on_boot(True)
 
 
 def stop_client_and_disable_init_script():
+    """
+    Stop landscape-client and change configuration to prevent starting
+    landscape-client on boot.
+    """
     sysvconfig = SysVConfig()
     sysvconfig.stop_landscape()
     sysvconfig.set_start_on_boot(False)
 
 
+def setup_http_proxy(config):
+    """
+    If a http_proxy and a https_proxy value are not set then copy the values,
+    if any, from the environment variables L{http_proxy} and L{https_proxy}.
+    """
+    if config.http_proxy is None and os.environ.get("http_proxy"):
+        config.http_proxy = os.environ["http_proxy"]
+    if config.https_proxy is None and os.environ.get("https_proxy"):
+        config.https_proxy = os.environ["https_proxy"]
+
+
+def check_account_name_and_password(config):
+    """
+    Ensure that silent configurations which plan to start landscape-client are
+    either configured for OTP or have both an account_name and computer title.
+    """
+    if config.silent and not config.no_start:
+        if not (config.get("otp") or config.provisioning_otp or
+                (config.get("account_name") and config.get("computer_title"))):
+            raise ConfigurationError("An account name and computer title are "
+                                     "required.")
+
+
+def check_script_users(config):
+    """
+    If the configuration allows for script execution ensure that the configured
+    users are valid for that purpose.
+    """
+    if config.get("script_users"):
+        invalid_users = get_invalid_users(config.get("script_users"))
+        if invalid_users:
+            raise ConfigurationError("Unknown system users: %s" %
+                                     ", ".join(invalid_users))
+        if not config.include_manager_plugins:
+            config.include_manager_plugins = "ScriptExecution"
+
+
+def decode_base64_ssl_public_certificate(config):
+    """
+    Decode base64 encoded SSL certificate and push that back into place in the
+    config object.
+    """
+    # WARNING: ssl_public_certificate is misnamed, it's not the key of the
+    # certificate, but the actual certificate itself.
+    if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
+        decoded_cert = base64.decodestring(config.ssl_public_key[7:])
+        config.ssl_public_key = store_public_key_data(
+            config, decoded_cert)
+
+
+def fetch_base64_ssl_public_certificate(hostname, on_info=print_text,
+    on_error=print_text):
+    """
+    Fetch base64 encoded SSL CA certificate from the discovered landscape
+    server and return that decoded info.
+    """
+    on_info("Fetching CA certificate from %s if available..." % hostname)
+    content = ""
+    encoded_cert = ""
+    ca_url = "http://%s/get-ca-cert" % hostname
+    try:
+        content = fetch(ca_url, insecure=True)
+    except HTTPCodeError, error:
+        on_error("Unable to fetch CA certificate from discovered server %s: "
+                 "Server does not support client auto-registation." % hostname)
+        return encoded_cert
+    except FetchError, error:
+        on_error("Unable to fetch CA certificate from %s: %s"
+                % (hostname, str(error)))
+        return encoded_cert
+
+    if content:
+        ca_dict = json.loads(content)
+        try:
+            if ca_dict["custom_ca_cert"].startswith("base64:"):
+                encoded_cert = ca_dict["custom_ca_cert"]
+            else:
+                on_error("Auto-registration URL %s returns invalid CA JSON: "
+                         "%s." % (ca_url, ca_dict))
+        except KeyError:
+            # No custom CA certificate needed to talk with this server
+            on_info("No custom CA certificate available for %s." % hostname)
+    else:
+        on_error("Unable to fetch CA certificate from discovered server "
+                 "%s.  Proceding without custom CA certificate."
+                % hostname)
+    return encoded_cert
+
+
 def setup(config):
+    """
+    Perform steps to ensure that landscape-client is correctly configured
+    before we attempt to register it with a landscape server.
+
+    If we are not configured to be silent then interrogate the user to provide
+    necessary details for registration.
+    """
     sysvconfig = SysVConfig()
     if not config.no_start:
         if config.silent:
@@ -434,34 +550,14 @@ def setup(config):
             else:
                 sys.exit("Aborting Landscape configuration")
 
-    if config.http_proxy is None and os.environ.get("http_proxy"):
-        config.http_proxy = os.environ["http_proxy"]
-    if config.https_proxy is None and os.environ.get("https_proxy"):
-        config.https_proxy = os.environ["https_proxy"]
-
+    setup_http_proxy(config)
+    check_account_name_and_password(config)
     if config.silent:
-        if not config.get("otp") and (not config.get("account_name") or not
-                                          config.get("computer_title")):
-            raise ConfigurationError("An account name and computer title are "
-                                     "required.")
-        if config.get("script_users"):
-            invalid_users = get_invalid_users(config.get("script_users"))
-            if invalid_users:
-                raise ConfigurationError("Unknown system users: %s" %
-                                         ", ".join(invalid_users))
-            if not config.include_manager_plugins:
-                config.include_manager_plugins = "ScriptExecution"
+        check_script_users(config)
     else:
         script = LandscapeSetupScript(config)
         script.run()
-
-    # WARNING: ssl_public_key is misnamed, it's not the key of the certificate,
-    # but the actual certificate itself.
-    if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
-        decoded_cert = base64.decodestring(config.ssl_public_key[7:])
-        config.ssl_public_key = store_public_key_data(
-            config, decoded_cert)
-
+    decode_base64_ssl_public_certificate(config)
     config.write()
     # Restart the client to ensure that it's using the new configuration.
     if not config.no_start and not config.otp:
@@ -497,7 +593,7 @@ def store_public_key_data(config, certificate_data):
     return key_filename
 
 
-def register(config, reactor=None):
+def register(config, on_message=print_text, on_error=sys.exit, reactor=None):
     """Instruct the Landscape Broker to register the client.
 
     The broker will be instructed to reload its configuration and then to
@@ -510,29 +606,28 @@ def register(config, reactor=None):
     reactor = TwistedReactor()
     exit_with_error = []
 
-    # XXX: many of these reactor.stop() calls should also specify a non-0 exit
-    # code, unless ok-no-register is passed.
-
-    def stop():
+    def stop(error=None):
+        if not config.ok_no_register and error is not None:
+            exit_with_error.append(error)
         connector.disconnect()
         reactor.stop()
 
     def failure():
-        print_text("Invalid account name or "
+        on_message("Invalid account name or "
                    "registration password.", error=True)
-        stop()
+        stop(2)
 
     def success():
-        print_text("System successfully registered.")
+        on_message("System successfully registered.")
         stop()
 
     def exchange_failure():
-        print_text("We were unable to contact the server. "
+        on_message("We were unable to contact the server. "
                    "Your internet connection may be down. "
                    "The landscape client will continue to try and contact "
                    "the server periodically.",
                    error=True)
-        stop()
+        stop(2)
 
     def handle_registration_errors(failure):
         # We'll get invalid credentials through the signal.
@@ -540,15 +635,11 @@ def register(config, reactor=None):
         connector.disconnect()
 
     def catch_all(failure):
-        # We catch SecurityError here too, because on some DBUS configurations
-        # if you try to connect to a dbus name that doesn't have a listener,
-        # it'll try auto-starting the service, but then the StartServiceByName
-        # call can raise a SecurityError.
-        print_text(failure.getTraceback(), error=True)
-        print_text("Unknown error occurred.", error=True)
-        stop()
+        on_message(failure.getTraceback(), error=True)
+        on_message("Unknown error occurred.", error=True)
+        stop(2)
 
-    print_text("Please wait... ", "")
+    on_message("Please wait... ", "")
 
     time.sleep(2)
 
@@ -566,13 +657,11 @@ def register(config, reactor=None):
         return results.addErrback(catch_all)
 
     def got_error(failure):
-        print_text("There was an error communicating with the Landscape "
-                   "client.", error=True)
-        print_text("This machine will be registered with the provided "
+        on_message("There was an error communicating with the Landscape"
+                   " client.", error=True)
+        on_message("This machine will be registered with the provided "
                    "details when the client runs.", error=True)
-        if not config.ok_no_register:
-            exit_with_error.append(2)
-        stop()
+        stop(2)
 
     connector = RemoteBrokerConnector(reactor, config)
     result = connector.connect(max_retries=0, quiet=True)
@@ -582,33 +671,13 @@ def register(config, reactor=None):
     reactor.run()
 
     if exit_with_error:
-        sys.exit(exit_with_error[0])
+        on_error(exit_with_error[0])
 
     return result
 
 
-def fetch_import_url(url):
-    """Handle fetching of URLs passed to --url.
-
-    This is done out of LandscapeSetupConfiguration since it has to deal
-    with interaction with the user and downloading of files.
-    """
-
-    print_text("Fetching configuration from %s..." % url)
-    error_message = None
-    try:
-        content = fetch(url)
-    except FetchError, error:
-        error_message = str(error)
-    if error_message is not None:
-        raise ImportOptionError(
-            "Couldn't download configuration from %s: %s" %
-            (url, error_message))
-    return content
-
-
 def main(args):
-    config = LandscapeSetupConfiguration(fetch_import_url)
+    config = LandscapeSetupConfiguration()
     if args in (["-h"], ["--help"]):
         # We let landscape-config --help to be run as normal user
         config.load(args)
@@ -622,7 +691,6 @@ def main(args):
         print_text(str(error), error=True)
         sys.exit(1)
 
-
     # Disable startup on boot and stop the client, if one is running.
     if config.disable:
         stop_client_and_disable_init_script()
