@@ -4,7 +4,7 @@ import sys
 from logging import (getLevelName, getLogger,
                      FileHandler, StreamHandler, Formatter)
 
-from optparse import OptionParser
+from optparse import OptionParser, SUPPRESS_HELP
 from ConfigParser import ConfigParser, NoSectionError
 
 from landscape import VERSION
@@ -18,7 +18,7 @@ def init_logging(configuration, program_name):
     handlers = []
     if not os.path.exists(configuration.log_dir):
         os.makedirs(configuration.log_dir)
-    log_filename = os.path.join(configuration.log_dir, program_name+".log")
+    log_filename = os.path.join(configuration.log_dir, program_name + ".log")
     handlers.append(FileHandler(log_filename))
     if not configuration.quiet:
         handlers.append(StreamHandler(sys.stdout))
@@ -40,6 +40,8 @@ class BaseConfiguration(object):
         command-line options that should never end up in a configuration file.
     @cvar default_config_filenames: A sequence of filenames to check when
         reading or writing a configuration.
+
+    Default values for supported options are set as in L{make_parser}.
     """
 
     required_options = ()
@@ -52,10 +54,6 @@ class BaseConfiguration(object):
     config_section = "client"
 
     def __init__(self):
-        """Default configuration.
-
-        Default values for supported options are set as in L{make_parser}.
-        """
         self._set_options = {}
         self._command_line_args = []
         self._command_line_options = {}
@@ -99,6 +97,17 @@ class BaseConfiguration(object):
                 value = option.convert_value(None, value)
         return value
 
+    def clone(self):
+        """
+        Return a new configuration object, with the same settings as this one.
+        """
+        config = self.__class__()
+        config._set_options = self._set_options.copy()
+        config._command_line_options = self._command_line_options.copy()
+        config._config_filename = self._config_filename
+        config._config_file_options = self._config_file_options.copy()
+        return config
+
     def get(self, name, default=None):
         """Return the value of the C{name} option or C{default}."""
         try:
@@ -191,6 +200,7 @@ class BaseConfiguration(object):
         The filename picked for saving configuration options is the one
         returned by L{get_config_filename}.
         """
+
         # The filename we'll write to
         filename = self.get_config_filename()
 
@@ -261,6 +271,8 @@ class Configuration(BaseConfiguration):
     This contains all simple data, some of it calculated.
     """
 
+    DEFAULT_URL = "https://landscape.canonical.com/message-system"
+
     def make_parser(self):
         """Parser factory for supported options.
 
@@ -270,6 +282,13 @@ class Configuration(BaseConfiguration):
               - C{quiet} (C{False})
               - C{log_dir} (C{"/var/log/landscape"})
               - C{log_level} (C{"info"})
+              - C{url} (C{"http://landscape.canonical.com/message-system"})
+              - C{ping_url} (C{"http://landscape.canonical.com/ping"})
+              - C{ssl_public_key}
+              - C{server_autodiscover} (C{"false"})
+              - C{autodiscover_srv_query_string}
+                    (C{"_tcp._landscape.localdomain"})
+              - C{autodiscover_a_query_string} (C{"landscape.localdomain"})
               - C{ignore_sigint} (C{False})
         """
         parser = super(Configuration, self).make_parser()
@@ -286,14 +305,46 @@ class Configuration(BaseConfiguration):
         parser.add_option("--log-level", default="info",
                           help="One of debug, info, warning, error or "
                                "critical.")
+        parser.add_option("-u", "--url", default=self.DEFAULT_URL,
+                          help="The server URL to connect to.")
+        parser.add_option("--ping-url",
+                          help="The URL to perform lightweight exchange "
+                               "initiation with.")
+        parser.add_option("-k", "--ssl-public-key",
+                          help="The public SSL key to verify the server. "
+                               "Only used if the given URL is https.")
+        parser.add_option("--server-autodiscover", type="string",
+                          default=False, help="Enable server autodiscovery.")
+        parser.add_option("--autodiscover-srv-query-string", type="string",
+                          default="_landscape._tcp.localdomain",
+                          help="autodiscovery string for DNS SRV queries")
+        parser.add_option("--autodiscover-a-query-string", type="string",
+                          default="landscape.localdomain",
+                          help="autodiscovery string for DNS A queries")
         parser.add_option("--ignore-sigint", action="store_true",
                           default=False, help="Ignore interrupt signals.")
         parser.add_option("--ignore-sigusr1", action="store_true",
                           default=False, help="Ignore SIGUSR1 signal to "
                                               "rotate logs.")
 
+        # Hidden options, used for load-testing to run in-process clones
+        parser.add_option("--clones", default=0, type=int, help=SUPPRESS_HELP)
+        parser.add_option("--start-clones-over", default=25 * 60, type=int,
+                          help=SUPPRESS_HELP)
+
         return parser
 
+    def load(self, args, accept_nonexistent_config=False):
+        """
+        Load configuration data from command line arguments and a config file.
+        """
+        super(Configuration, self).load(
+            args, accept_nonexistent_config=accept_nonexistent_config)
+
+        if not isinstance(self.server_autodiscover, bool):
+            autodiscover = str(self.server_autodiscover).lower()
+            self.server_autodiscover = (autodiscover == "true")
+
     @property
     def sockets_path(self):
         """Return the path to the directory where Unix sockets are created."""
