@@ -231,6 +231,24 @@ class FetchTest(LandscapeTest):
         else:
             self.fail("PyCurlError not raised")
 
+    def test_pycurl_insecure(self):
+        curl = CurlStub("result")
+        result = fetch("http://example.com/get-ca-cert", curl=curl,
+                       insecure=True)
+        self.assertEqual(result, "result")
+        self.assertEqual(curl.options,
+                         {pycurl.URL: "http://example.com/get-ca-cert",
+                          pycurl.FOLLOWLOCATION: True,
+                          pycurl.MAXREDIRS: 5,
+                          pycurl.CONNECTTIMEOUT: 30,
+                          pycurl.LOW_SPEED_LIMIT: 1,
+                          pycurl.LOW_SPEED_TIME: 600,
+                          pycurl.NOSIGNAL: 1,
+                          pycurl.WRITEFUNCTION: Any(),
+                          pycurl.SSL_VERIFYPEER: False,
+                          pycurl.DNS_CACHE_TIMEOUT: 0,
+                          pycurl.ENCODING: "gzip,deflate"})
+
     def test_pycurl_error_str(self):
         self.assertEqual(str(PyCurlError(60, "pycurl error")),
                          "Error 60: pycurl error")
@@ -318,7 +336,7 @@ class FetchTest(LandscapeTest):
         """
         url_results = {"http://right/": "right",
                        "http://wrong/": ("wrong", 501),
-                       "http://impossilbe/": "impossible"}
+                       "http://impossible/": "impossible"}
         failed_urls = []
 
         def errback(failure, url):
@@ -328,7 +346,8 @@ class FetchTest(LandscapeTest):
             return failure
 
         curl = CurlManyStub(url_results)
-        result = fetch_many_async(url_results.keys(), callback=None,
+        urls = ["http://right/", "http://wrong/", "http://impossible/"]
+        result = fetch_many_async(urls, callback=None,
                                   errback=errback, curl=curl)
 
         def check_failure(failure):
