@@ -1,6 +1,8 @@
+import os
+
 from landscape.tests.helpers import LandscapeTest
 
-from landscape.lib.fs import read_file, touch_file
+from landscape.lib.fs import append_file, read_file, touch_file
 
 
 class ReadFileTest(LandscapeTest):
@@ -59,3 +61,23 @@ class TouchFileTest(LandscapeTest):
         touch_file(path)
         touch_file(path)
         self.assertFileContent(path, "")
+
+
+class AppendFileTest(LandscapeTest):
+
+    def test_append_existing_file(self):
+        """
+        The L{append_file} function appends contents to an existing file.
+        """
+        existing_file = self.makeFile("foo bar")
+        append_file(existing_file, " baz")
+        self.assertFileContent(existing_file, "foo bar baz")
+
+    def test_append_no_file(self):
+        """
+        The L{append_file} function creates a new file if one doesn't
+        exist already.
+        """
+        new_file = os.path.join(self.makeDir(), "new_file")
+        append_file(new_file, "contents")
+        self.assertFileContent(new_file, "contents")
