@@ -4,13 +4,17 @@ import sys
 import tempfile
 import stat
 
-from twisted.internet.defer import gatherResults
+from twisted.internet.defer import gatherResults, succeed, fail
 from twisted.internet.error import ProcessDone
 from twisted.python.failure import Failure
 
+from landscape import VERSION
+from landscape.lib.fetch import HTTPCodeError
+from landscape.lib.persist import Persist
 from landscape.manager.scriptexecution import (
     ScriptExecutionPlugin, ProcessTimeLimitReachedError, PROCESS_FAILED_RESULT,
-    UBUNTU_PATH, get_user_info, UnknownInterpreterError, UnknownUserError)
+    UBUNTU_PATH, get_user_info, UnknownInterpreterError, UnknownUserError,
+    FETCH_ATTACHMENTS_FAILED_RESULT)
 from landscape.manager.manager import SUCCEEDED, FAILED
 from landscape.tests.helpers import (
     LandscapeTest, ManagerHelper, StubProcessFactory, DummyProcess)
@@ -61,8 +65,50 @@ class RunScriptTests(LandscapeTest):
             "import os\nprint os.environ")
 
         def check_environment(results):
-            for string in get_default_environment().keys():
+            for string in get_default_environment():
                 self.assertIn(string, results)
+
+        result.addCallback(check_environment)
+        return result
+
+    def test_server_supplied_env(self):
+        """
+        Server-supplied environment variables are merged with default
+        variables then passed to script.
+        """
+        server_supplied_env = {"DOG": "Woof", "CAT": "Meow"}
+        result = self.plugin.run_script(
+            sys.executable,
+            "import os\nprint os.environ",
+            server_supplied_env=server_supplied_env)
+
+        def check_environment(results):
+            for string in get_default_environment():
+                self.assertIn(string, results)
+            for name, value in server_supplied_env.items():
+                self.assertIn(name, results)
+                self.assertIn(value, results)
+
+        result.addCallback(check_environment)
+        return result
+
+    def test_server_supplied_env_overrides_client(self):
+        """
+        Server-supplied environment variables override client default
+        values if the server provides them.
+        """
+        server_supplied_env = {"PATH": "server-path", "USER": "server-user",
+                               "HOME": "server-home"}
+        result = self.plugin.run_script(
+            sys.executable,
+            "import os\nprint os.environ",
+            server_supplied_env=server_supplied_env)
+
+        def check_environment(results):
+            for name, value in server_supplied_env.items():
+                self.assertIn(name, results)
+                self.assertIn(value, results)
+
         result.addCallback(check_environment)
         return result
 
@@ -105,6 +151,7 @@ class RunScriptTests(LandscapeTest):
         def check(result):
             self.assertTrue(
                 "%s " % (accented_content.encode("utf-8"),) in result)
+
         result.addCallback(check)
         return result
 
@@ -138,7 +185,7 @@ class RunScriptTests(LandscapeTest):
         self.mocker.replay()
         result = self.plugin.run_script("/bin/sh", "umask",
                                         attachments={u"file1": "some data"})
-        self.assertFailure(result, OSError)
+        return self.assertFailure(result, OSError)
 
     def test_run_with_attachments(self):
         result = self.plugin.run_script(
@@ -148,6 +195,73 @@ class RunScriptTests(LandscapeTest):
 
         def check(result):
             self.assertEqual(result, "file1\nsome data")
+
+        result.addCallback(check)
+        return result
+
+    def test_run_with_attachment_ids(self):
+        """
+        The most recent protocol for script message doesn't include the
+        attachment body inside the message itself, but instead gives an
+        attachment ID, and the plugin fetches the files separately.
+        """
+        self.manager.config.url = "https://localhost/message-system"
+        persist = Persist(
+            filename=os.path.join(self.config.data_path, "broker.bpickle"))
+        registration_persist = persist.root_at("registration")
+        registration_persist.set("secure-id", "secure_id")
+        persist.save()
+        mock_fetch = self.mocker.replace("landscape.lib.fetch.fetch_async",
+                                         passthrough=False)
+        headers = {"User-Agent": "landscape-client/%s" % VERSION,
+                   "Content-Type": "application/octet-stream",
+                   "X-Computer-ID": "secure_id"}
+        mock_fetch("https://localhost/attachment/14", headers=headers,
+                   cainfo=None)
+        self.mocker.result(succeed("some other data"))
+        self.mocker.replay()
+
+        result = self.plugin.run_script(
+            u"/bin/sh",
+            u"ls $LANDSCAPE_ATTACHMENTS && cat $LANDSCAPE_ATTACHMENTS/file1",
+            attachments={u"file1": 14})
+
+        def check(result):
+            self.assertEqual(result, "file1\nsome other data")
+
+        result.addCallback(check)
+        return result
+
+    def test_run_with_attachment_ids_and_ssl(self):
+        """
+        When fetching attachments, L{ScriptExecution} passes the optional ssl
+        certificate file if the configuration specifies it.
+        """
+        self.manager.config.url = "https://localhost/message-system"
+        self.manager.config.ssl_public_key = "/some/key"
+        persist = Persist(
+            filename=os.path.join(self.config.data_path, "broker.bpickle"))
+        registration_persist = persist.root_at("registration")
+        registration_persist.set("secure-id", "secure_id")
+        persist.save()
+        mock_fetch = self.mocker.replace("landscape.lib.fetch.fetch_async",
+                                         passthrough=False)
+        headers = {"User-Agent": "landscape-client/%s" % VERSION,
+                   "Content-Type": "application/octet-stream",
+                   "X-Computer-ID": "secure_id"}
+        mock_fetch("https://localhost/attachment/14", headers=headers,
+                   cainfo="/some/key")
+        self.mocker.result(succeed("some other data"))
+        self.mocker.replay()
+
+        result = self.plugin.run_script(
+            u"/bin/sh",
+            u"ls $LANDSCAPE_ATTACHMENTS && cat $LANDSCAPE_ATTACHMENTS/file1",
+            attachments={u"file1": 14})
+
+        def check(result):
+            self.assertEqual(result, "file1\nsome other data")
+
         result.addCallback(check)
         return result
 
@@ -172,6 +286,7 @@ class RunScriptTests(LandscapeTest):
 
         def check(result):
             self.assertEqual(result, "file1\n")
+
         result.addCallback(check)
         return result
 
@@ -180,6 +295,9 @@ class RunScriptTests(LandscapeTest):
         mock_chown = self.mocker.replace("os.chown", passthrough=False)
         mock_chown(ARGS)
 
+        expected_uid = uid if uid != os.getuid() else None
+        expected_gid = gid if gid != os.getgid() else None
+
         factory = StubProcessFactory()
         self.plugin.process_factory = factory
 
@@ -190,8 +308,8 @@ class RunScriptTests(LandscapeTest):
         self.assertEqual(len(factory.spawns), 1)
         spawn = factory.spawns[0]
         self.assertEqual(spawn[4], path)
-        self.assertEqual(spawn[5], uid)
-        self.assertEqual(spawn[6], gid)
+        self.assertEqual(spawn[5], expected_uid)
+        self.assertEqual(spawn[6], expected_gid)
         result.addCallback(self.assertEqual, "foobar")
 
         protocol = spawn[0]
@@ -252,7 +370,7 @@ class RunScriptTests(LandscapeTest):
 
         self.assertEqual(len(factory.spawns), 1)
         spawn = factory.spawns[0]
-        self.assertIn("LANDSCAPE_ATTACHMENTS", spawn[3].keys())
+        self.assertIn("LANDSCAPE_ATTACHMENTS", spawn[3])
         attachment_dir = spawn[3]["LANDSCAPE_ATTACHMENTS"]
         self.assertEqual(stat.S_IMODE(os.stat(attachment_dir).st_mode), 0700)
         filename = os.path.join(attachment_dir, "file 1")
@@ -267,6 +385,7 @@ class RunScriptTests(LandscapeTest):
         def check(data):
             self.assertEqual(data, "foobar")
             self.assertFalse(os.path.exists(attachment_dir))
+
         return result.addCallback(check)
 
     def test_limit_size(self):
@@ -311,6 +430,7 @@ class RunScriptTests(LandscapeTest):
         def got_error(f):
             self.assertTrue(f.check(ProcessTimeLimitReachedError))
             self.assertEqual(f.value.data, "hi\n")
+
         result.addErrback(got_error)
         return result
 
@@ -347,6 +467,7 @@ class RunScriptTests(LandscapeTest):
 
         def got_result(output):
             self.assertEqual(output, "hi")
+
         result.addCallback(got_result)
         return result
 
@@ -379,7 +500,7 @@ class RunScriptTests(LandscapeTest):
         script_file.write("#!/bin/sh\ncode")
         script_file.close()
         process_factory.spawnProcess(
-            ANY, ANY, uid=uid, gid=gid, path=ANY,
+            ANY, ANY, uid=None, gid=None, path=ANY,
             env=get_default_environment())
         self.mocker.replay()
         # We don't really care about the deferred that's returned, as long as
@@ -437,15 +558,18 @@ class ScriptExecutionMessageTests(LandscapeTest):
 
     def _send_script(self, interpreter, code, operation_id=123,
                      user=pwd.getpwuid(os.getuid())[0],
-                     time_limit=None):
-        return self.manager.dispatch_message(
-            {"type": "execute-script",
-             "interpreter": interpreter,
-             "code": code,
-             "operation-id": operation_id,
-             "username": user,
-             "time-limit": time_limit,
-             "attachments": {}})
+                     time_limit=None, attachments={},
+                     server_supplied_env=None):
+        message = {"type": "execute-script",
+                   "interpreter": interpreter,
+                   "code": code,
+                   "operation-id": operation_id,
+                   "username": user,
+                   "time-limit": time_limit,
+                   "attachments": dict(attachments)}
+        if server_supplied_env:
+            message["env"] = server_supplied_env
+        return self.manager.dispatch_message(message)
 
     def test_success(self):
         """
@@ -481,6 +605,53 @@ class ScriptExecutionMessageTests(LandscapeTest):
                   "operation-id": 123,
                   "status": SUCCEEDED,
                   "result-text": u"hi!\n"}])
+
+        result.addCallback(got_result)
+        return result
+
+    def test_success_with_server_supplied_env(self):
+        """
+        When a C{execute-script} message is received from the server, the
+        specified script will be run with the supplied environment and an
+        operation-result will be sent back to the server.
+        """
+        # Let's use a stub process factory, because otherwise we don't have
+        # access to the deferred.
+        factory = StubProcessFactory()
+
+        # ignore the call to chown!
+        mock_chown = self.mocker.replace("os.chown", passthrough=False)
+        mock_chown(ARGS)
+
+        self.manager.add(ScriptExecutionPlugin(process_factory=factory))
+
+        self.mocker.replay()
+        result = self._send_script(sys.executable, "print 'hi'",
+                                   server_supplied_env={"Dog": "Woof"})
+
+        self._verify_script(factory.spawns[0][1], sys.executable, "print 'hi'")
+        # Verify environment was passed
+        self.assertIn("HOME", factory.spawns[0][3])
+        self.assertIn("USER", factory.spawns[0][3])
+        self.assertIn("PATH", factory.spawns[0][3])
+        self.assertIn("Dog", factory.spawns[0][3])
+        self.assertEqual("Woof", factory.spawns[0][3]["Dog"])
+
+        self.assertMessages(
+            self.broker_service.message_store.get_pending_messages(), [])
+
+        # Now let's simulate the completion of the process
+        factory.spawns[0][0].childDataReceived(1, "Woof\n")
+        factory.spawns[0][0].processEnded(Failure(ProcessDone(0)))
+
+        def got_result(r):
+            self.assertMessages(
+                self.broker_service.message_store.get_pending_messages(),
+                [{"type": "operation-result",
+                  "operation-id": 123,
+                  "status": SUCCEEDED,
+                  "result-text": u"Woof\n"}])
+
         result.addCallback(got_result)
         return result
 
@@ -497,9 +668,10 @@ class ScriptExecutionMessageTests(LandscapeTest):
             protocol.childDataReceived(1, "hi!\n")
             protocol.processEnded(Failure(ProcessDone(0)))
             self._verify_script(filename, sys.executable, "print 'hi'")
+
         process_factory = self.mocker.mock()
         process_factory.spawnProcess(
-            ANY, ANY, uid=uid, gid=gid, path=ANY,
+            ANY, ANY, uid=None, gid=None, path=ANY,
             env=get_default_environment())
         self.mocker.call(spawn_called)
         self.mocker.replay()
@@ -562,6 +734,7 @@ class ScriptExecutionMessageTests(LandscapeTest):
                   "status": FAILED,
                   "result-text": u"ONOEZ",
                   "result-code": 102}])
+
         result.addCallback(got_result)
         return result
 
@@ -581,14 +754,12 @@ class ScriptExecutionMessageTests(LandscapeTest):
                   "operation-id": 123,
                   "status": FAILED,
                   "result-text": u"Scripts cannot be run as user whatever."}])
+
         result.addCallback(got_result)
         return result
 
     def test_urgent_response(self):
         """Responses to script execution messages are urgent."""
-        username = pwd.getpwuid(os.getuid())[0]
-        uid, gid, home = get_user_info(username)
-
         # ignore the call to chown!
         mock_chown = self.mocker.replace("os.chown", passthrough=False)
         mock_chown(ARGS)
@@ -597,9 +768,10 @@ class ScriptExecutionMessageTests(LandscapeTest):
             protocol.childDataReceived(1, "hi!\n")
             protocol.processEnded(Failure(ProcessDone(0)))
             self._verify_script(filename, sys.executable, "print 'hi'")
+
         process_factory = self.mocker.mock()
         process_factory.spawnProcess(
-            ANY, ANY, uid=uid, gid=gid, path=ANY,
+            ANY, ANY, uid=None, gid=None, path=ANY,
             env=get_default_environment())
         self.mocker.call(spawn_called)
 
@@ -626,9 +798,6 @@ class ScriptExecutionMessageTests(LandscapeTest):
         If a script outputs non-printable characters not handled by utf-8, they
         are replaced during the encoding phase but the script succeeds.
         """
-        username = pwd.getpwuid(os.getuid())[0]
-        uid, gid, home = get_user_info(username)
-
         mock_chown = self.mocker.replace("os.chown", passthrough=False)
         mock_chown(ARGS)
 
@@ -637,9 +806,10 @@ class ScriptExecutionMessageTests(LandscapeTest):
             "\x7fELF\x01\x01\x01\x00\x00\x00\x95\x01")
             protocol.processEnded(Failure(ProcessDone(0)))
             self._verify_script(filename, sys.executable, "print 'hi'")
+
         process_factory = self.mocker.mock()
         process_factory.spawnProcess(
-            ANY, ANY, uid=uid, gid=gid, path=ANY,
+            ANY, ANY, uid=None, gid=None, path=ANY,
             env=get_default_environment())
         self.mocker.call(spawn_called)
 
@@ -709,6 +879,7 @@ class ScriptExecutionMessageTests(LandscapeTest):
                   "result-text": "hi\n",
                   "result-code": PROCESS_FAILED_RESULT,
                   "status": FAILED}])
+
         return result.addCallback(got_result)
 
     def test_unknown_error(self):
@@ -742,5 +913,42 @@ class ScriptExecutionMessageTests(LandscapeTest):
                   "operation-id": 123,
                   "status": FAILED,
                   "result-text": str(failure)}])
+
         result.addCallback(got_result)
         return result
+
+    def test_fetch_attachment_failure(self):
+        """
+        If the plugin fails to retrieve the attachments with a
+        L{HTTPCodeError}, a specific error code is shown.
+        """
+        self.manager.config.url = "https://localhost/message-system"
+        persist = Persist(
+            filename=os.path.join(self.config.data_path, "broker.bpickle"))
+        registration_persist = persist.root_at("registration")
+        registration_persist.set("secure-id", "secure_id")
+        persist.save()
+        mock_fetch = self.mocker.replace("landscape.lib.fetch.fetch_async",
+                                         passthrough=False)
+        headers = {"User-Agent": "landscape-client/%s" % VERSION,
+                   "Content-Type": "application/octet-stream",
+                   "X-Computer-ID": "secure_id"}
+        mock_fetch("https://localhost/attachment/14", headers=headers,
+                   cainfo=None)
+        self.mocker.result(fail(HTTPCodeError(404, "Not found")))
+        self.mocker.replay()
+
+        self.manager.add(ScriptExecutionPlugin())
+        result = self._send_script(
+            "/bin/sh", "echo hi", attachments={u"file1": 14})
+
+        def got_result(ignored):
+            self.assertMessages(
+                self.broker_service.message_store.get_pending_messages(),
+                [{"type": "operation-result",
+                  "operation-id": 123,
+                  "result-text": "Server returned HTTP code 404",
+                  "result-code": FETCH_ATTACHMENTS_FAILED_RESULT,
+                  "status": FAILED}])
+
+        return result.addCallback(got_result)
