@@ -16,10 +16,12 @@ class ComputerInfo(MonitorPlugin):
 
     def __init__(self, get_fqdn=get_fqdn,
                  meminfo_file="/proc/meminfo",
-                 lsb_release_filename=LSB_RELEASE_FILENAME):
+                 lsb_release_filename=LSB_RELEASE_FILENAME,
+                 root_path="/"):
         self._get_fqdn = get_fqdn
         self._meminfo_file = meminfo_file
         self._lsb_release_filename = lsb_release_filename
+        self._root_path = root_path
 
     def register(self, registry):
         super(ComputerInfo, self).register(registry)
