@@ -9,8 +9,8 @@ import grp
 from twisted.internet.defer import maybeDeferred, succeed
 
 from landscape.constants import (
-    SUCCESS_RESULT, ERROR_RESULT, DEPENDENCY_ERROR_RESULT, POLICY_STRICT,
-    POLICY_ALLOW_INSTALLS, POLICY_ALLOW_ALL_CHANGES,
+    SUCCESS_RESULT, ERROR_RESULT, DEPENDENCY_ERROR_RESULT,
+    POLICY_STRICT, POLICY_ALLOW_INSTALLS, POLICY_ALLOW_ALL_CHANGES,
     UNKNOWN_PACKAGE_DATA_TIMEOUT)
 
 from landscape.lib.fs import create_file
@@ -18,7 +18,7 @@ from landscape.package.reporter import find_reporter_command
 from landscape.package.taskhandler import (
     PackageTaskHandler, PackageTaskHandlerConfiguration, PackageTaskError,
     run_task_handler)
-from landscape.manager.manager import SUCCEEDED
+from landscape.manager.manager import FAILED
 
 
 class UnknownPackageData(Exception):
@@ -38,7 +38,7 @@ class ChangePackagesResult(object):
     """Value object to hold the results of change packages operation.
 
     @ivar code: The result code of the requested changes.
-    @ivar text: The output from Smart.
+    @ivar text: The output from Apt.
     @ivar installs: Possible additional packages that need to be installed
         in order to fulfill the request.
     @ivar removals: Possible additional packages that need to be removed
@@ -63,7 +63,7 @@ class PackageChanger(PackageTaskHandler):
         """
         Handle our tasks and spawn the reporter if package data has changed.
         """
-        if not self.smart_update_stamp_exists():
+        if not self.update_stamp_exists():
             logging.warning("The package-reporter hasn't run yet, exiting.")
             return succeed(None)
 
@@ -80,10 +80,6 @@ class PackageChanger(PackageTaskHandler):
             # Nothing was done
             return
 
-        # In order to let the reporter run smart-update cleanly,
-        # we have to deinitialize Smart, so that the write lock
-        # gets released
-        self._facade.deinit()
         if os.getuid() == 0:
             os.setgid(grp.getgrnam("landscape").gr_gid)
             os.setuid(pwd.getpwnam("landscape").pw_uid)
@@ -127,14 +123,23 @@ class PackageChanger(PackageTaskHandler):
         else:
             raise PackageTaskError()
 
-    def smart_update_stamp_exists(self):
+    def update_stamp_exists(self):
         """
-        Return a boolean indicating if the smart-update stamp file exists.
+        Return a boolean indicating if the update-stamp stamp file exists.
         """
-        return os.path.exists(self._config.smart_update_stamp_filename)
+        return os.path.exists(self._config.update_stamp_filename)
+
+    def _clear_binaries(self):
+        """Remove any binaries and its associated channel."""
+        binaries_path = self._config.binaries_path
+
+        for existing_deb_path in os.listdir(binaries_path):
+            # Clean up the binaries we wrote in former runs
+            os.remove(os.path.join(binaries_path, existing_deb_path))
+        self._facade.clear_channels()
 
     def init_channels(self, binaries=()):
-        """Initialize the Smart channels as needed.
+        """Initialize the Apt channels as needed.
 
         @param binaries: A possibly empty list of 3-tuples of the form
             (hash, id, deb), holding the hash, the id and the content of
@@ -142,9 +147,8 @@ class PackageChanger(PackageTaskHandler):
         """
         binaries_path = self._config.binaries_path
 
-        for existing_deb_path in os.listdir(binaries_path):
-            # Clean up the binaries we wrote in former runs
-            os.remove(os.path.join(binaries_path, existing_deb_path))
+        # Clean up the binaries we wrote in former runs
+        self._clear_binaries()
 
         if binaries:
             hash_ids = {}
@@ -154,35 +158,41 @@ class PackageChanger(PackageTaskHandler):
                 hash_ids[hash] = id
             self._store.set_hash_ids(hash_ids)
             self._facade.add_channel_deb_dir(binaries_path)
+            self._facade.reload_channels(force_reload_binaries=True)
 
         self._facade.ensure_channels_reloaded()
 
-    def mark_packages(self, upgrade=False, install=(), remove=(), reset=True):
+    def mark_packages(self, upgrade=False, install=(), remove=(),
+                      hold=(), remove_hold=(), reset=True):
         """Mark packages for upgrade, installation or removal.
 
         @param upgrade: If C{True} mark all installed packages for upgrade.
         @param install: A list of package ids to be marked for installation.
         @param remove: A list of package ids to be marked for removal.
+        @param hold: A list of package ids to be marked for holding.
+        @param remove_hold: A list of package ids to be marked to have a hold
+                            removed.
         @param reset: If C{True} all existing marks will be reset.
         """
         if reset:
             self._facade.reset_marks()
 
         if upgrade:
-            for package in self._facade.get_packages():
-                if package.installed:
-                    self._facade.mark_upgrade(package)
+            self._facade.mark_global_upgrade()
 
-        for ids, mark_func in [(install, self._facade.mark_install),
-                                 (remove, self._facade.mark_remove)]:
-            for id in ids:
-                hash = self._store.get_id_hash(id)
+        for mark_function, mark_ids in [
+            (self._facade.mark_install, install),
+            (self._facade.mark_remove, remove),
+            (self._facade.mark_hold, hold),
+            (self._facade.mark_remove_hold, remove_hold)]:
+            for mark_id in mark_ids:
+                hash = self._store.get_id_hash(mark_id)
                 if hash is None:
-                    raise UnknownPackageData(id)
+                    raise UnknownPackageData(mark_id)
                 package = self._facade.get_package_by_hash(hash)
                 if package is None:
                     raise UnknownPackageData(hash)
-                mark_func(package)
+                mark_function(package)
 
     def change_packages(self, policy):
         """Perform the requested changes.
@@ -193,10 +203,9 @@ class PackageChanger(PackageTaskHandler):
         @return: A L{ChangePackagesResult} holding the details about the
             outcome of the requested changes.
         """
-        # Delay importing these so that we don't import Smart unless
+        # Delay importing these so that we don't import Apt unless
         # we really need to.
-        from landscape.package.facade import (
-            DependencyError, TransactionError, SmartError)
+        from landscape.package.facade import DependencyError, TransactionError
 
         result = ChangePackagesResult()
         count = 0
@@ -204,7 +213,7 @@ class PackageChanger(PackageTaskHandler):
             count += 1
             try:
                 result.text = self._facade.perform_changes()
-            except (TransactionError, SmartError), exception:
+            except TransactionError, exception:
                 result.code = ERROR_RESULT
                 result.text = exception.args[0]
             except DependencyError, exception:
@@ -215,7 +224,7 @@ class PackageChanger(PackageTaskHandler):
                         # Will have to wait until the server lets us know about
                         # this id.
                         raise UnknownPackageData(hash)
-                    if package.installed:
+                    if self._facade.is_package_installed(package):
                         # Package currently installed. Must remove it.
                         result.removals.append(id)
                     else:
@@ -255,11 +264,13 @@ class PackageChanger(PackageTaskHandler):
         """Handle a C{change-packages} message."""
 
         self.init_channels(message.get("binaries", ()))
-        self.mark_packages(message.get("upgrade-all", False),
-                           message.get("install", ()),
-                           message.get("remove", ()))
-
+        self.mark_packages(upgrade=message.get("upgrade-all", False),
+                           install=message.get("install", ()),
+                           remove=message.get("remove", ()),
+                           hold=message.get("hold", ()),
+                           remove_hold=message.get("remove-hold", ()))
         result = self.change_packages(message.get("policy", POLICY_STRICT))
+        self._clear_binaries()
 
         response = {"type": "change-packages-result",
                    "operation-id": message.get("operation-id")}
@@ -272,7 +283,6 @@ class PackageChanger(PackageTaskHandler):
         if result.removals:
             response["must-remove"] = sorted(result.removals)
 
-
         logging.info("Queuing response with change package results to "
                      "exchange urgently.")
         return self._broker.send_message(response, True)
@@ -280,23 +290,15 @@ class PackageChanger(PackageTaskHandler):
     def handle_change_package_locks(self, message):
         """Handle a C{change-package-locks} message.
 
-        Create and delete package locks as requested by the given C{message}.
+        Package locks aren't supported anymore.
         """
 
-        for lock in message.get("create", ()):
-            self._facade.set_package_lock(*lock)
-        for lock in message.get("delete", ()):
-            self._facade.remove_package_lock(*lock)
-        self._facade.save_config()
-
-        response = {"type": "operation-result",
-                    "operation-id": message.get("operation-id"),
-                    "status": SUCCEEDED,
-                    "result-text": "Package locks successfully changed.",
-                    "result-code": 0}
-
-        logging.info("Queuing message with change package locks results to "
-                     "exchange urgently.")
+        response = {
+            "type": "operation-result",
+            "operation-id": message.get("operation-id"),
+            "status": FAILED,
+            "result-text": "This client doesn't support package locks.",
+            "result-code": 1}
         return self._broker.send_message(response, True)
 
     @staticmethod
