@@ -14,7 +14,6 @@ from landscape.package.releaseupgrader import (
     ReleaseUpgrader, ReleaseUpgraderConfiguration, main)
 from landscape.tests.helpers import (
     LandscapeTest, BrokerServiceHelper, LogKeeperHelper, EnvironSaverHelper)
-from landscape.package.tests.helpers import SmartFacadeHelper
 from landscape.manager.manager import SUCCEEDED, FAILED
 
 
@@ -33,7 +32,7 @@ class ReleaseUpgraderConfigurationTest(unittest.TestCase):
 
 class ReleaseUpgraderTest(LandscapeTest):
 
-    helpers = [LogKeeperHelper, SmartFacadeHelper,
+    helpers = [LogKeeperHelper,
                EnvironSaverHelper, BrokerServiceHelper]
 
     def setUp(self):
@@ -44,7 +43,7 @@ class ReleaseUpgraderTest(LandscapeTest):
             os.mkdir(self.config.package_directory)
             os.mkdir(self.config.upgrade_tool_directory)
             self.store = PackageStore(self.makeFile())
-            self.upgrader = ReleaseUpgrader(self.store, self.facade,
+            self.upgrader = ReleaseUpgrader(self.store, None,
                                             self.remote, self.config)
             service = self.broker_service
             service.message_store.set_accepted_types(["operation-result"])
@@ -656,7 +655,7 @@ class ReleaseUpgraderTest(LandscapeTest):
 
             def check_result((out, err, code)):
                 self.assertFalse(os.path.exists(upgrade_tool_directory))
-                self.assertEqual(out, "--force-smart-update\n%s\n"
+                self.assertEqual(out, "--force-apt-update\n%s\n"
                                   % os.getcwd())
                 self.assertEqual(err, "")
                 self.assertEqual(code, 0)
@@ -702,7 +701,7 @@ class ReleaseUpgraderTest(LandscapeTest):
         spawn_process_calls = []
 
         def spawn_process(pp, reporter, args=None, uid=None, gid=None,
-                          path=None, env=None):
+                          path=None, env=None, usePTY=None):
             self.assertEqual(uid, 1234)
             self.assertEqual(gid, 5678)
             spawn_process_calls.append(True)
@@ -739,7 +738,7 @@ class ReleaseUpgraderTest(LandscapeTest):
             result = self.upgrader.finish()
 
             def check_result((out, err, code)):
-                self.assertEqual(out, "--force-smart-update "
+                self.assertEqual(out, "--force-apt-update "
                                        "--config=/some/config\n")
                 self.assertEqual(err, "")
                 self.assertEqual(code, 0)
