@@ -9,10 +9,11 @@ from landscape.broker.amp import RemoteBrokerConnector
 from landscape.package.taskhandler import (
     PackageTaskHandlerConfiguration, PackageTaskHandler, run_task_handler,
     LazyRemoteBroker)
-from landscape.package.facade import SmartFacade
+from landscape.package.facade import AptFacade
 from landscape.package.store import HashIdStore, PackageStore
-from landscape.package.tests.helpers import SmartFacadeHelper
-from landscape.tests.helpers import LandscapeTest, BrokerServiceHelper
+from landscape.package.tests.helpers import AptFacadeHelper
+from landscape.tests.helpers import (
+    LandscapeTest, BrokerServiceHelper, EnvironSaverHelper)
 from landscape.tests.mocker import ANY, ARGS, MATCH
 
 
@@ -25,20 +26,20 @@ SAMPLE_LSB_RELEASE = "DISTRIB_CODENAME=codename\n"
 
 class PackageTaskHandlerConfigurationTest(LandscapeTest):
 
-    def test_force_smart_update_option(self):
+    def test_update_stamp_option(self):
         """
-        L{PackageReporterConfiguration.smart_update_stamp_filename} points
-        to the smart-update stamp file.
+        L{PackageReporterConfiguration.update_stamp_filename} points
+        to the update-stamp file.
         """
         config = PackageTaskHandlerConfiguration()
         self.assertEqual(
-            config.smart_update_stamp_filename,
-            "/var/lib/landscape/client/package/smart-update-stamp")
+            config.update_stamp_filename,
+            "/var/lib/landscape/client/package/update-stamp")
 
 
 class PackageTaskHandlerTest(LandscapeTest):
 
-    helpers = [SmartFacadeHelper, BrokerServiceHelper]
+    helpers = [AptFacadeHelper, EnvironSaverHelper, BrokerServiceHelper]
 
     def setUp(self):
 
@@ -316,10 +317,11 @@ class PackageTaskHandlerTest(LandscapeTest):
         self.assertTrue(isinstance(result, Deferred))
         self.assertTrue(result.called)
 
-    def test_run_task_handler(self):
+    def _mock_run_task_handler(self):
         """
-        The L{run_task_handler} function creates and runs the given task
-        handler with the proper arguments.
+        Mock the different parts of run_task_handler(), to ensure it
+        does what it's supposed to do, without actually creating files
+        and starting processes.
         """
         # This is a slightly lengthy one, so bear with me.
 
@@ -369,6 +371,15 @@ class PackageTaskHandlerTest(LandscapeTest):
         # Okay, the whole playground is set.
         self.mocker.replay()
 
+        return HandlerMock, handler_args
+
+    def test_run_task_handler(self):
+        """
+        The L{run_task_handler} function creates and runs the given task
+        handler with the proper arguments.
+        """
+        HandlerMock, handler_args = self._mock_run_task_handler()
+
         def assert_task_handler(ignored):
 
             store, facade, broker, config = handler_args
@@ -376,7 +387,7 @@ class PackageTaskHandlerTest(LandscapeTest):
             try:
                 # Verify the arguments passed to the reporter constructor.
                 self.assertEqual(type(store), PackageStore)
-                self.assertEqual(type(facade), SmartFacade)
+                self.assertEqual(type(facade), AptFacade)
                 self.assertEqual(type(broker), LazyRemoteBroker)
                 self.assertEqual(type(config),
                                  PackageTaskHandlerConfiguration)
