@@ -1,4 +1,3 @@
-import thread
 import time
 import sys
 import logging
@@ -8,6 +7,7 @@ import socket
 from twisted.test.proto_helpers import FakeDatagramTransport
 from twisted.internet.defer import succeed, fail
 from twisted.internet.error import DNSLookupError
+from twisted.internet.threads import deferToThread
 
 from landscape.log import format_object
 
@@ -21,14 +21,14 @@ class CallHookError(Exception):
 
 
 class EventID(object):
-    """Unique identifier for an event handler."""
+    """Unique identifier for an event handler.
+
+    @param event_type: Name of the event type handled by the handler.
+    @param pair: Binary tuple C{(handler, priority)} holding the handler
+        function and its priority.
+    """
 
     def __init__(self, event_type, pair):
-        """
-        @param event_type: Name of the event type handled by the handler.
-        @param pair: Binary tuple C{(handler, priority)} holding the handler
-            function and its priority.
-        """
         self._event_type = event_type
         self._pair = pair
 
@@ -124,8 +124,20 @@ class ThreadedCallsReactorMixin(object):
         @note: Both C{callback} and C{errback} will be executed in the
             the parent thread.
         """
-        thread.start_new_thread(self._in_thread,
-                                (callback, errback, f, args, kwargs))
+        def on_success(result):
+            if callback:
+                return callback(result)
+
+        def on_failure(failure):
+            exc_info = (failure.type, failure.value, failure.tb)
+            if errback:
+                errback(*exc_info)
+            else:
+                logging.error(exc_info[1], exc_info=exc_info)
+
+        deferred = deferToThread(f, *args, **kwargs)
+        deferred.addCallback(on_success)
+        deferred.addErrback(on_failure)
 
     def _in_thread(self, callback, errback, f, args, kwargs):
         try:
@@ -289,12 +301,12 @@ class FakeReactor(EventHandlingReactorMixin,
         try:
             # is it an IP address?
             socket.inet_aton(hostname)
-        except socket.error: # no
+        except socket.error:  # no
             if hostname in self.hosts:
                 return succeed(self.hosts[hostname])
             else:
                 return fail(DNSLookupError(hostname))
-        else: # yes
+        else:  # yes
             return succeed(hostname)
 
 
@@ -308,7 +320,7 @@ class TwistedReactor(EventHandlingReactorMixin,
         self._LoopingCall = LoopingCall
         self._reactor = reactor
         self._cleanup()
-
+        self.callFromThread = reactor.callFromThread
         super(TwistedReactor, self).__init__()
 
     def _cleanup(self):
