@@ -1,4 +1,5 @@
 from cStringIO import StringIO
+from ConfigParser import ConfigParser
 import logging
 import shutil
 import pprint
@@ -7,6 +8,7 @@ import os
 import sys
 import unittest
 
+
 from logging import Handler, ERROR, Formatter
 from twisted.trial.unittest import TestCase
 from twisted.internet.defer import Deferred
@@ -74,8 +76,8 @@ class MessageTestCase(unittest.TestCase):
                                            pprint.pformat(obtained)))
 
     def assertMessages(self, obtained, expected):
-        self.assertEquals(type(obtained), list)
-        self.assertEquals(type(expected), list)
+        self.assertEqual(type(obtained), list)
+        self.assertEqual(type(expected), list)
         for obtained_message, expected_message in zip(obtained, expected):
             self.assertMessage(obtained_message, expected_message)
         obtained_len = len(obtained)
@@ -121,13 +123,33 @@ class LandscapeTest(MessageTestCase, MockerTestCase,
         Assert that the given C{deferred} results in the given C{result}.
         """
         self.assertTrue(isinstance(deferred, Deferred))
-        return deferred.addCallback(self.assertEquals, result)
+        return deferred.addCallback(self.assertEqual, result)
 
     def assertFileContent(self, filename, expected_content):
         fd = open(filename)
         actual_content = fd.read()
         fd.close()
-        self.assertEquals(expected_content, actual_content)
+        self.assertEqual(expected_content, actual_content)
+
+    def assertConfigEqual(self, first, second):
+        """
+        Compare two configuration files for equality.  The order of parameters
+        and comments may be different but the actual parameters and sections
+        must be the same.
+        """
+        first_fp = StringIO(first)
+        first_parser = ConfigParser()
+        first_parser.readfp(first_fp)
+
+        second_fp = StringIO(second)
+        second_parser = ConfigParser()
+        second_parser.readfp(second_fp)
+
+        self.assertEqual(set(first_parser.sections()),
+                         set(second_parser.sections()))
+        for section in first_parser.sections():
+            self.assertEqual(dict(first_parser.items(section)),
+                             dict(second_parser.items(section)))
 
     def makePersistFile(self, *args, **kwargs):
         """Return a temporary filename to be used by a L{Persist} object.
@@ -474,7 +496,10 @@ class DummyProcess(object):
 
 
 class ProcessDataBuilder(object):
-    """Builder creates sample data for the process info plugin to consume."""
+    """Builder creates sample data for the process info plugin to consume.
+
+    @param sample_dir: The directory for sample data.
+    """
 
     RUNNING = "R (running)"
     STOPPED = "T (stopped)"
@@ -485,7 +510,6 @@ class ProcessDataBuilder(object):
     ZOMBIE = "Z (zombie)"
 
     def __init__(self, sample_dir):
-        """Initialize factory with directory for sample data."""
         self._sample_dir = sample_dir
 
     def create_data(self, process_id, state, uid, gid,
@@ -610,7 +634,7 @@ def install_trial_hack():
         if self._shared and self not in self.__class__._instances:
             self.__class__._instances.add(self)
         result.startTest(self)
-        if self.getSkip(): # don't run test methods that are marked as .skip
+        if self.getSkip():  # don't run test methods that are marked as .skip
             result.addSkip(self, self.getSkip())
             result.stopTest(self)
             return
@@ -641,6 +665,7 @@ def install_trial_hack():
 
 ### Copied from Twisted, to fix a bug in trial in Twisted 2.2! ###
 
+
 class UnsupportedTrialFeature(Exception):
     """A feature of twisted.trial was used that pyunit cannot support."""
 
@@ -651,12 +676,11 @@ class PyUnitResultAdapter(object):
     supports the extended result types from Trial, and also supports
     L{twisted.python.failure.Failure}s being passed to L{addError} and
     L{addFailure}.
+
+    @param original: A C{TestResult} instance from C{unittest}.
     """
 
     def __init__(self, original):
-        """
-        @param original: A C{TestResult} instance from C{unittest}.
-        """
         self.original = original
 
     def _exc_info(self, err):
