@@ -1,4 +1,5 @@
 import os
+import sys
 from getpass import getpass
 from ConfigParser import ConfigParser
 from cStringIO import StringIO
@@ -11,7 +12,8 @@ from landscape.configuration import (
     print_text, LandscapeSetupScript, LandscapeSetupConfiguration,
     register, setup, main, setup_init_script_and_start_client,
     stop_client_and_disable_init_script, ConfigurationError,
-    fetch_import_url, ImportOptionError, store_public_key_data)
+    ImportOptionError, store_public_key_data,
+    fetch_base64_ssl_public_certificate)
 from landscape.broker.registration import InvalidCredentialsError
 from landscape.sysvconfig import SysVConfig, ProcessError
 from landscape.tests.helpers import (
@@ -27,7 +29,7 @@ def get_config(self, args):
 url = https://landscape.canonical.com/message-system
 """)
         args.extend(["--config", filename, "--data-path", self.makeDir()])
-    config = LandscapeSetupConfiguration(fetch_import_url)
+    config = LandscapeSetupConfiguration()
     config.load(args)
     return config
 
@@ -91,7 +93,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
 
         class MyLandscapeSetupConfiguration(LandscapeSetupConfiguration):
             default_config_filenames = [self.config_filename]
-        self.config = MyLandscapeSetupConfiguration(None)
+        self.config = MyLandscapeSetupConfiguration()
         self.script = LandscapeSetupScript(self.config)
 
     def test_show_help(self):
@@ -712,14 +714,66 @@ class ConfigurationFunctionsTest(LandscapeTest):
 
         config = self.get_config(["--silent", "-a", "account", "-t", "rex"])
         setup(config)
-        self.assertEqual(self.get_content(config), """\
+        self.assertConfigEqual(self.get_content(config), """\
 [client]
-url = https://landscape.canonical.com/message-system
 computer_title = rex
 data_path = %s
 account_name = account
 """ % config.data_path)
 
+    def test_silent_setup_no_register(self):
+        """
+        Called with command line options to write a config file but no
+        registration or validation of parameters is attempted.
+        """
+        # Make sure no sysvconfig modifications are attempted
+        self.mocker.patch(SysVConfig)
+        self.mocker.replay()
+
+        config = self.get_config(["--silent", "--no-start"])
+        setup(config)
+        self.assertConfigEqual(self.get_content(config), """\
+[client]
+data_path = %s
+""" % config.data_path)
+
+    def test_silent_setup_no_register_with_default_preseed_params(self):
+        """
+        Make sure that the configuration can be used to write the
+        configuration file after a fresh install.
+        """
+        # Make sure no sysvconfig modifications are attempted
+        self.mocker.patch(SysVConfig)
+        self.mocker.replay()
+
+        args = ["--silent", "--no-start",
+                "--computer-title", "",
+                "--account-name", "",
+                "--registration-password", "",
+                "--url", "https://landscape.canonical.com/message-system",
+                "--exchange-interval", "900",
+                "--urgent-exchange-interval", "60",
+                "--ping-url", "http://landscape.canonical.com/ping",
+                "--ping-interval", "30",
+                "--http-proxy", "",
+                "--https-proxy", "",
+                "--otp", "",
+                "--tags", "",
+                "--provisioning-otp", ""]
+        config = self.get_config(args)
+        setup(config)
+        self.assertConfigEqual(self.get_content(config),
+            "[client]\n"
+            "http_proxy = \n"
+            "tags = \n"
+            "data_path = %s\n"
+            "registration_password = \n"
+            "account_name = \n"
+            "computer_title = \n"
+            "https_proxy = \n"
+            "ping_url = http://landscape.canonical.com/ping\n"
+             % config.data_path)
+
     def test_silent_setup_without_computer_title(self):
         """A computer title is required."""
         sysvconfig_mock = self.mocker.patch(SysVConfig)
@@ -752,6 +806,21 @@ account_name = account
 
         self.assertEqual("otp1", config.otp)
 
+    def test_silent_setup_with_provisioning_otp(self):
+        """
+        If the provisioning OTP is specified, there is no need to pass the
+        account name and the computer title.
+        """
+        sysvconfig_mock = self.mocker.patch(SysVConfig)
+        sysvconfig_mock.set_start_on_boot(True)
+        sysvconfig_mock.restart_landscape()
+        self.mocker.replay()
+
+        config = self.get_config(["--silent", "--provisioning-otp", "otp1"])
+        setup(config)
+
+        self.assertEqual("otp1", config.provisioning_otp)
+
     def test_silent_script_users_imply_script_execution_plugin(self):
         """
         If C{--script-users} is specified, without C{ScriptExecution} in the
@@ -813,7 +882,6 @@ bus = session
 
         filename = self.makeFile("""
 [client]
-url = https://landscape.canonical.com/message-system
 ping_url = http://landscape.canonical.com/ping
 registration_password = shared-secret
 log_level = debug
@@ -828,7 +896,6 @@ random_key = random_value
         self.assertEqual(
             {"log_level": "debug",
              "registration_password": "shared-secret",
-             "url": "https://landscape.canonical.com/message-system",
              "ping_url": "http://localhost/ping",
              "random_key": "random_value",
              "computer_title": "rex",
@@ -870,7 +937,6 @@ random_key = random_value
 
         filename = self.makeFile("""
 [client]
-url = https://landscape.canonical.com/message-system
 registration_password = shared-secret
 """)
         config = self.get_config(["--config", filename, "--silent",
@@ -880,7 +946,6 @@ registration_password = shared-secret
         parser.read(filename)
         self.assertEqual(
             {"registration_password": "shared-secret",
-             "url": "https://landscape.canonical.com/message-system",
              "http_proxy": "http://environ",
              "https_proxy": "https://environ",
              "computer_title": "rex",
@@ -928,6 +993,28 @@ registration_password = shared-secret
 
         main(["-c", self.make_working_config()])
 
+    def test_main_silent(self):
+        """
+        In silent mode, the client should register when the registration
+        details are changed/set.
+        """
+        setup_mock = self.mocker.replace(setup)
+        setup_mock(ANY)
+
+        register_mock = self.mocker.replace(register, passthrough=False)
+        register_mock(ANY)
+        self.mocker.count(1)
+
+        self.mocker.replay()
+
+        config_filename = self.makeFile(
+            "[client]\n"
+            "computer_title = Old Title\n"
+            "account_name = Old Name\n"
+            "registration_password = Old Password\n"
+            )
+        main(["-c", config_filename, "--silent"])
+
     def make_working_config(self):
         return self.makeFile("[client]\n"
                              "computer_title = Old Title\n"
@@ -1073,7 +1160,7 @@ registration_password = shared-secret
 
         # Registration logic should not be invoked.
         register_mock = self.mocker.replace(register, passthrough=False)
-        register_mock(ANY)
+        register_mock(ANY, ANY, ANY)
         self.mocker.count(0)
 
         self.mocker.replay()
@@ -1535,6 +1622,11 @@ class RegisterFunctionTest(LandscapeTest):
 
     helpers = [BrokerServiceHelper]
 
+    def setUp(self):
+        super(RegisterFunctionTest, self).setUp()
+        self.config = LandscapeSetupConfiguration()
+        self.config.load(["-c", self.config_filename])
+
     def test_register_success(self):
         service = self.broker_service
 
@@ -1579,7 +1671,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.replay()
 
         # DO IT!
-        return register(service.config)
+        return register(self.config, print_text, sys.exit)
 
     def test_register_failure(self):
         """
@@ -1631,7 +1723,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.replay()
 
         # DO IT!
-        return register(service.config)
+        return register(self.config, print_text, sys.exit)
 
     def test_register_exchange_failure(self):
         """
@@ -1681,7 +1773,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.replay()
 
         # DO IT!
-        return register(service.config)
+        return register(self.config, print_text, sys.exit)
 
     def test_register_timeout_failure(self):
         service = self.broker_service
@@ -1725,7 +1817,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.replay()
 
         # DO IT!
-        return register(service.config)
+        return register(self.config, print_text, sys.exit)
 
     def test_register_bus_connection_failure(self):
         """
@@ -1762,7 +1854,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.replay()
 
         config = get_config(self, ["-a", "accountname", "--silent"])
-        return register(config)
+        return register(config, print_text, sys.exit)
 
     def test_register_bus_connection_failure_ok_no_register(self):
         """
@@ -1789,7 +1881,7 @@ class RegisterFunctionTest(LandscapeTest):
 
         config = get_config(self, ["-a", "accountname", "--silent",
                                    "--ok-no-register"])
-        return self.assertSuccess(register(config))
+        return self.assertSuccess(register(config, print_text, sys.exit))
 
 
 class RegisterFunctionNoServiceTest(LandscapeTest):
@@ -1799,7 +1891,8 @@ class RegisterFunctionNoServiceTest(LandscapeTest):
         When registration fails because of an unknown error, a message is
         printed and the program exits.
         """
-        configuration = LandscapeSetupConfiguration(None)
+        configuration = LandscapeSetupConfiguration()
+        configuration.ok_no_register = True
 
         # We'll just mock the remote here to have it raise an exception.
         connector_factory = self.mocker.replace(
@@ -1842,10 +1935,10 @@ class RegisterFunctionNoServiceTest(LandscapeTest):
 
         self.mocker.replay()
 
-        return register(configuration)
+        return register(configuration, print_text, sys.exit)
 
 
-class StoreSSLCertificateDataTest(LandscapeTest):
+class SSLCertificateDataTest(LandscapeTest):
 
     def test_store_public_key_data(self):
         """
@@ -1865,3 +1958,84 @@ class StoreSSLCertificateDataTest(LandscapeTest):
         self.assertEqual(key_filename,
                          store_public_key_data(config, "123456789"))
         self.assertEqual("123456789", open(key_filename, "r").read())
+
+    def test_fetch_base64_ssl(self):
+        """
+        L{fetch_base64_ssl_public_certificate} should pull a JSON object from
+        http://providedhostname/get-ca-cert. And return the custom_ca_cert data
+        if it exists.
+        """
+        base64_cert = "base64:  MTIzNDU2Nzg5MA=="  # encoded woo hoo
+        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
+        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
+        self.mocker.result(
+            "{\"custom_ca_cert\": \"%s\"}" % base64_cert)
+        self.mocker.replay()
+
+        def check_info(info):
+            self.assertEqual(
+                "Fetching CA certificate from fakehost if available...",
+                str(info))
+
+        content = fetch_base64_ssl_public_certificate("fakehost",
+                                                      on_info=check_info)
+        self.assertEqual(base64_cert, content)
+
+    def test_fetch_base64_ssl_no_custom_ca(self):
+        """
+        L{fetch_base64_ssl_public_certificate} should pull a JSON object from
+        http://providedhostname/get-ca-cert. And return the custom_ca_cert data
+        if it exists, otherwise it should return an empty string.""
+        """
+        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
+        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
+        self.mocker.result("{}")
+
+        print_text_mock = self.mocker.replace(print_text)
+        print_text_mock(
+            "Fetching CA certificate from fakehost if available...")
+        print_text_mock("No custom CA certificate available for fakehost.")
+        self.mocker.replay()
+
+        content = fetch_base64_ssl_public_certificate("fakehost",
+                                                      on_info=print_text)
+        self.assertEqual("", content)
+
+    def test_fetch_base64_ssl_with_http_code_fetch_error(self):
+        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
+        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
+        self.mocker.throw(HTTPCodeError(404, ""))
+        print_text_mock = self.mocker.replace(print_text)
+        print_text_mock(
+            "Fetching CA certificate from fakehost if available...")
+        self.mocker.replay()
+
+        def check_error(error):
+            self.assertEqual("Unable to fetch CA certificate from discovered "
+                             "server fakehost: Server does not support client "
+                             "auto-registation.",
+                             str(error))
+
+        content = fetch_base64_ssl_public_certificate("fakehost",
+                                                      on_info=print_text,
+                                                      on_error=check_error)
+        self.assertEquals("", content)
+
+    def test_fetch_base64_ssl_with_pycurl_error(self):
+        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
+        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
+        self.mocker.throw(PyCurlError(60, "pycurl message"))
+        print_text_mock = self.mocker.replace(print_text)
+        print_text_mock(
+            "Fetching CA certificate from fakehost if available...")
+        self.mocker.replay()
+
+        def check_error(error):
+            self.assertEqual("Unable to fetch CA certificate from fakehost: "
+                             "Error 60: pycurl message",
+                             str(error))
+
+        content = fetch_base64_ssl_public_certificate("fakehost",
+                                                      on_info=print_text,
+                                                      on_error=check_error)
+        self.assertEquals("", content)
