@@ -13,6 +13,7 @@ import signal
 import time
 
 from logging import warning, info, error
+from resource import setrlimit, RLIMIT_NOFILE
 
 from twisted.internet import reactor
 from twisted.internet.defer import Deferred, succeed
@@ -21,19 +22,23 @@ from twisted.internet.error import ProcessExitedAlready
 from twisted.application.service import Service, Application
 from twisted.application.app import startApplication
 
-from landscape.deployment import Configuration, init_logging
+from landscape.deployment import init_logging, Configuration
 from landscape.lib.twisted_util import gather_results
 from landscape.lib.log import log_failure
 from landscape.lib.bootstrap import (BootstrapList, BootstrapFile,
                                      BootstrapDirectory)
 from landscape.log import rotate_logs
+from landscape.amp import ComponentProtocol
 from landscape.broker.amp import (
     RemoteBrokerConnector, RemoteMonitorConnector, RemoteManagerConnector)
 from landscape.reactor import TwistedReactor
+from landscape.lib.dns import discover_server
+from landscape.configuration import (
+    fetch_base64_ssl_public_certificate, decode_base64_ssl_public_certificate)
 
 GRACEFUL_WAIT_PERIOD = 10
 MAXIMUM_CONSECUTIVE_RESTARTS = 5
-RESTART_BURST_DELAY = 30 # seconds
+RESTART_BURST_DELAY = 30  # seconds
 SIGKILL_DELAY = 10
 
 
@@ -63,21 +68,21 @@ class Daemon(object):
         trying to connect to the watched daemon.
     @cvar factor: The factor by which the delay between subsequent connection
         attempts will increase.
+
+    @param connector: The L{RemoteComponentConnector} of the daemon.
+    @param reactor: The reactor used to spawn the process and schedule timed
+        calls.
+    @param verbose: Optionally, report more information when running this
+        program.  Defaults to False.
     """
 
     username = "landscape"
     max_retries = 3
     factor = 1.1
+    options = None
 
     def __init__(self, connector, reactor=reactor, verbose=False,
                  config=None):
-        """
-        @param connector: The L{RemoteComponentConnector} of the daemon.
-        @param reactor: The reactor used to spawn the process and schedule
-            timed calls.
-        @param verbose: Optionally, report more information when
-            running this program.  Defaults to False.
-        """
         self._connector = connector
         self._reactor = reactor
         self._env = os.environ.copy()
@@ -135,6 +140,8 @@ class Daemon(object):
             args.append("--quiet")
         if self._config:
             args.extend(["-c", self._config])
+        if self.options is not None:
+            args.extend(self.options)
         self._reactor.spawnProcess(self._process, exe, args=args,
                                    env=self._env, uid=self._uid, gid=self._gid)
 
@@ -334,6 +341,11 @@ class WatchDog(object):
         self._checking = None
         self._stopping = False
         signal.signal(signal.SIGUSR1, self._notify_rotate_logs)
+        if config is not None and config.clones > 0:
+            options = ["--clones", str(config.clones),
+                       "--start-clones-over", str(config.start_clones_over)]
+            for daemon in self.daemons:
+                daemon.options = options
 
         self._ping_failures = {}
 
@@ -456,11 +468,11 @@ class WatchDogConfiguration(Configuration):
 
 def daemonize():
     # See http://www.steve.org.uk/Reference/Unix/faq_2.html#SEC16
-    if os.fork():   # launch child and...
-        os._exit(0) # kill off parent
+    if os.fork():  # launch child and...
+        os._exit(0)  # kill off parent
     os.setsid()
-    if os.fork():   # launch child and...
-        os._exit(0) # kill off parent again.
+    if os.fork():  # launch child and...
+        os._exit(0)  # kill off parent again.
     # some argue that this umask should be 0, but that's annoying.
     os.umask(077)
     null = os.open('/dev/null', os.O_RDWR)
@@ -482,18 +494,76 @@ class WatchDogService(Service):
                                  enabled_daemons=config.get_enabled_daemons())
         self.exit_code = 0
 
+    def autodiscover(self):
+        """
+        Autodiscover called if config setting config.server_autodiscover is
+        True. This method allows the watchdog to attempt server autodiscovery,
+        fetch the discovered landscape server's custom CA certificate, and
+        write both the certificate and the updated config file with the
+        discovered values.
+        """
+        def update_config(hostname):
+            if hostname is None:
+                warning("Autodiscovery returned empty hostname string. "
+                        "Reverting to previous settings.")
+            else:
+                info("Autodiscovery found landscape server at %s. "
+                     "Updating configuration values." % hostname)
+                self._config.server_autodiscover = False
+                self._config.url = "https://%s/message-system" % hostname
+                self._config.ping_url = "http://%s/ping" % hostname
+                if not self._config.ssl_public_key:
+                    # If we don't have a key on this system, pull it from
+                    # the auto-discovered server and write it to the filesystem
+                    ssl_public_key = fetch_base64_ssl_public_certificate(
+                        hostname, on_info=info, on_error=warning)
+                    if ssl_public_key:
+                        self._config.ssl_public_key = ssl_public_key
+                        decode_base64_ssl_public_certificate(self._config)
+                self._config.write()
+            return hostname
+
+        def discovery_error(result):
+            warning("Autodiscovery failed.  Reverting to previous settings.")
+
+        lookup_deferred = discover_server(
+            self._config.autodiscover_srv_query_string,
+            self._config.autodiscover_a_query_string)
+        lookup_deferred.addCallback(update_config)
+        lookup_deferred.addErrback(discovery_error)
+        return lookup_deferred
+
     def startService(self):
         Service.startService(self)
         bootstrap_list.bootstrap(data_path=self._config.data_path,
                                  log_dir=self._config.log_dir)
-        result = self.watchdog.check_running()
+        if self._config.clones > 0:
+
+            # Let clones open an appropriate number of fds
+            setrlimit(RLIMIT_NOFILE, (self._config.clones * 100,
+                                      self._config.clones * 200))
+
+            # Increase the timeout of AMP's MethodCalls
+            ComponentProtocol.timeout = 300
+
+            # Create clones log and data directories
+            for i in range(self._config.clones):
+                suffix = "-clone-%d" % i
+                bootstrap_list.bootstrap(
+                    data_path=self._config.data_path + suffix,
+                    log_dir=self._config.log_dir + suffix)
+
+        result = succeed(None)
+        if self._config.server_autodiscover:
+            result.addCallback(lambda _: self.autodiscover())
+        result.addCallback(lambda _: self.watchdog.check_running())
 
         def start_if_not_running(running_daemons):
             if running_daemons:
                 error("ERROR: The following daemons are already running: %s"
                       % (", ".join(x.program for x in running_daemons)))
                 self.exit_code = 1
-                reactor.crash() # so stopService isn't called.
+                reactor.crash()  # so stopService isn't called.
                 return
             self._daemonize()
             info("Watchdog watching for daemons.")
@@ -561,7 +631,7 @@ def clean_environment():
     In particular unset all variables beginning with DEBIAN_ or DEBCONF_,
     to avoid any problems when landscape-client is invoked from its
     postinst script.  Some environment variables may be set which would affect
-    *other* maintainer scripts which landscape-client invokes (via smart).
+    *other* maintainer scripts which landscape-client invokes.
     """
     for key in os.environ.keys():
         if (key.startswith("DEBIAN_")
